@@ -296,7 +296,8 @@ class Turkish(TurkishClass):
             self.harden_verb()
 
             if self.last_letter_is_vowel():
-                self.change_last_letter(self.minor())
+                self.word = self.word[:-1]
+                self.concat(self.minor())
             else:
                 self.concat(self.minor())
         else:
@@ -583,7 +584,12 @@ class Turkish(TurkishClass):
         elif person == 2:
             self.concat(f'{letter_d}{minor}n{minor}z')
         elif person == 3:
-            self.concat(f'd{self.minor()}')
+            if self.last_letter_is_vowel() or not self.last_letter_is_hard():
+                letter_d = 'd'
+            else:
+                letter_d = 't'
+
+            self.concat(f'{letter_d}{self.minor()}')
             self.plural()
 
         if kwargs.get('question', False):
@@ -991,6 +997,7 @@ class Turkish(TurkishClass):
         self.word = self.future_simple(person=3, negative=kwargs.get('negative')).to_string()
 
         letter_a = self.letter_a()
+        letter_i = self.letter_i()
 
         person = kwargs.get('person', 3)
         plural = kwargs.get('plural')
@@ -1006,10 +1013,10 @@ class Turkish(TurkishClass):
         elif person == 1 and plural:
             self.concat(f'k')
         elif person == 2 and plural:
-            self.concat(f'niz')
+            self.concat(f'n{letter_i}z')
 
         if kwargs.get('question'):
-            self.concat(' mi')
+            self.concat(' m{letter_i}')
 
         return self.common_return(**kwargs)
 
@@ -1299,36 +1306,34 @@ class Turkish(TurkishClass):
         """
 
         person = kwargs.get('person')
-        question = kwargs.get('negative')
         plural = kwargs.get('plural')
         negative = kwargs.get('negative')
+        question = kwargs.get('question')
 
-        if person == 3 and question and negative:
-            self.word = self.past_definite(
-                person=3,
-                plural=plural,
-                negative=negative,
-            ).to_string()
-        else:
-            self.word = self.past_definite(
-                person=3,
-                plural=False,
-                negative=negative,
-                question=question
-            ).to_string()
+        if self.is_from_passive():
+            negative = False
 
-            self.concat('y')
+        self.word = self.past_definite(
+            person=3,
+            plural=plural,
+            negative=negative,
+        ).to_string()
 
-        if person == 3 and question and plural:
+        if person == 3 and plural:
             self.plural()
 
-            self.concat(' m')
-            self.concat(self.letter_i())
-        else:
-            self.word = self.past_definite(
-                person=person,
-                plural=plural
-            ).to_string()
+        if question:
+            self.concat(f' m{self.minor()}')
+
+        self.if_ends_with_vowel('y')
+
+        if person == 3 and plural:
+            plural = False
+
+        self.word = self.past_definite(
+            person=person,
+            plural=plural
+        ).to_string()
 
         return self.common_return(**kwargs)
 
@@ -1384,28 +1389,33 @@ class Turkish(TurkishClass):
             Example: It is heard by someone that somebody did something in the past
         """
 
-        if kwargs.get('person') == 3 and kwargs.get('plural', False) and kwargs.get('question', False):
+        person = kwargs.get('person')
+        plural = kwargs.get('plural', 3)
+        question = kwargs.get('question')
+        negative = kwargs.get('negative')
+
+        if person == 3 and plural and question:
             self.word = self.indefinite_past(
-                negative=kwargs.get('negative', False),
-                question=kwargs.get('question', False),
-                person=kwargs.get('person', 3),
-                plural=kwargs.get('plural', False)
+                negative=negative,
+                question=question,
+                person=3,
+                plural=plural
             ).to_string()
         else:
             self.word = self.indefinite_past(
-                negative=kwargs.get('negative', False),
-                question=kwargs.get('question', False),
+                negative=negative,
+                question=question,
+                person=3
             ).to_string()
 
-        if kwargs.get('question', False):
-            self.concat('y')
+        self.if_ends_with_vowel('y')
 
-        if kwargs.get('person') == 3 and kwargs.get('plural', False) and kwargs.get('question', False):
-            self.word = self.past_definite(person=kwargs.get('person', 3)).to_string()
+        if person == 3 and plural and question:
+            self.word = self.past_definite(person=person).to_string()
         else:
             self.word = self.past_definite(
-                person=kwargs.get('person', 3),
-                plural=kwargs.get('plural', False)
+                person=person,
+                plural=plural
             ).to_string()
 
         return self.common_return(**kwargs)
@@ -1422,6 +1432,9 @@ class Turkish(TurkishClass):
         question = kwargs.get('question')
         negative = kwargs.get('negative')
 
+        if self.is_from_passive():
+            negative = False
+
         self.word = self.future_simple(
             negative=negative,
             person=3,
